@@ -30,8 +30,11 @@
 #include <dlfcn.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
+#ifndef _MSC_VER
+# include <unistd.h>
+#endif
 #include <dirent.h>
+
 #include "ao/ao.h"
 #include "ao_private.h"
 
@@ -389,7 +392,7 @@ int _realloc_swap_buffer(ao_device *device, int min_size)
    the target buffer. */
 void _swap_samples(char *target_buffer, char* source_buffer, uint_32 num_bytes)
 {
-	int i;
+	uint_32 i;
 
 	for (i = 0; i < num_bytes; i += 2) {
 		target_buffer[i] = source_buffer[i+1];
